Index — dfitspy 19.3.3 documentation

# Index

D | G | K | T

## D

dfitsort() (in module dfitspy.readfits) dfitsort_view() (in module dfitspy.display) dfitspy.display (module) | dfitspy.get_files_and_keys (module) dfitspy.readfits (module) dfitspy.tests (module)

## G

get_all_keyword() (in module dfitspy.readfits) | get_files() (in module dfitspy.get_files_and_keys) get_keys() (in module dfitspy.get_files_and_keys)

## K

keywords_view() (in module dfitspy.display)

## T

test() (in module dfitspy.tests)